package com.nisum.demo.mongo.service;

import com.nisum.demo.mongo.model.UserData;
import com.nisum.demo.mongo.model.UserRequest;
import com.nisum.demo.mongo.model.UserResponse;
import com.nisum.demo.mongo.repository.UserRepository;
import com.nisum.demo.mongo.repository.model.User;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

@Service
public class MongoDBDemoService {

    @Autowired
    private MongoTemplate mongoTemplate;

    @Autowired
    private UserRepository userRepository;

    public UserResponse getAllUserData() {
        UserResponse response = new UserResponse();
        List<UserData> users = new ArrayList<>();
        userRepository.findAll().forEach( u -> {
            UserData uData = new UserData();
            uData.setId(u.getId());
            uData.setUserId(u.getUserId());
            uData.setUserFirstName(u.getUserFirstName());
            uData.setUserLastName(u.getUserLastName());
            uData.setAddress(u.getAddress());
            users.add(uData);
        });

        response.setUsers(users);
        return response;
    }

    public UserResponse getUserData(String userId, String userName) throws Exception {
        List<User> userList = null;
        if (StringUtils.isNotEmpty(userId)) {
            userList = userRepository.findByUserId(userId);
        } else if (StringUtils.isNotEmpty(userName)) {
            userList = userRepository.findByUserFirstName(userName);
        } else {
            throw new Exception("Insufficient input");
        }

        UserResponse response = new UserResponse();
        List<UserData> users = new ArrayList<>();
        userList.forEach( u -> {
            UserData uData = new UserData();
            uData.setId(u.getId());
            uData.setUserId(u.getUserId());
            uData.setUserFirstName(u.getUserFirstName());
            uData.setUserLastName(u.getUserLastName());
            users.add(uData);
        });
        response.setUsers(users);
        return response;
    }

    public void deleteUserById(String userId) {
        userRepository.deleteByUserId(userId);
    }

    public void deleteAll() {
        userRepository.deleteAll();
    }

    public void addUser(UserRequest user) {
        User newUser = new User();
        newUser.setUserId(user.getUserId());
        newUser.setUserFirstName(user.getUserFirstName());
        newUser.setUserLastName(user.getUserLastName());
        userRepository.save(newUser);
    }

    public void updateUser(UserRequest userReq) throws Exception {
        List<User> userList = userRepository.findByUserId(userReq.getUserId());
        if (userList == null) {
            throw new Exception("No Users found");
        }
        List<User> updatedList = new ArrayList<>();
        userList.forEach(u -> {
            User user = new User();
            user.setId(u.getId());
            user.setUserId(u.getUserId());
            user.setUserFirstName(userReq.getUserFirstName());
            user.setUserLastName(userReq.getUserLastName());
            user.setAddress(userReq.getAddress());
            updatedList.add(user);
        });
        userRepository.saveAll(updatedList);
    }
}
